==> openshift-model-monitoring-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/RemoteReadSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface RemoteReadSpecFluent<A extends RemoteReadSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBasicAuth instead.
 * @return The buildable object.
 */
@Deprecated public BasicAuth getBasicAuth();
    public BasicAuth buildBasicAuth();
    public A withBasicAuth(BasicAuth basicAuth);
    public Boolean hasBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> withNewBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
    public RemoteReadSpecFluent.BasicAuthNested<A> editBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
    public String getBearerToken();
    public A withBearerToken(String bearerToken);
    public Boolean hasBearerToken();
    public A withNewBearerToken(String arg1);
    public A withNewBearerToken(StringBuilder arg1);
    public A withNewBearerToken(StringBuffer arg1);
    public String getBearerTokenFile();
    public A withBearerTokenFile(String bearerTokenFile);
    public Boolean hasBearerTokenFile();
    public A withNewBearerTokenFile(String arg1);
    public A withNewBearerTokenFile(StringBuilder arg1);
    public A withNewBearerTokenFile(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getProxyUrl();
    public A withProxyUrl(String proxyUrl);
    public Boolean hasProxyUrl();
    public A withNewProxyUrl(String arg1);
    public A withNewProxyUrl(StringBuilder arg1);
    public A withNewProxyUrl(StringBuffer arg1);
    public Boolean isReadRecent();
    public A withReadRecent(Boolean readRecent);
    public Boolean hasReadRecent();
    public A withNewReadRecent(String arg1);
    public A withNewReadRecent(boolean arg1);
    public String getRemoteTimeout();
    public A withRemoteTimeout(String remoteTimeout);
    public Boolean hasRemoteTimeout();
    public A withNewRemoteTimeout(String arg1);
    public A withNewRemoteTimeout(StringBuilder arg1);
    public A withNewRemoteTimeout(StringBuffer arg1);
    public A addToRequiredMatchers(String key,String value);
    public A addToRequiredMatchers(Map<String,String> map);
    public A removeFromRequiredMatchers(String key);
    public A removeFromRequiredMatchers(Map<String,String> map);
    public Map<String,String> getRequiredMatchers();
    public A withRequiredMatchers(Map<String,String> requiredMatchers);
    public Boolean hasRequiredMatchers();
    
/**
 * This method has been deprecated, please use method buildTlsConfig instead.
 * @return The buildable object.
 */
@Deprecated public TLSConfig getTlsConfig();
    public TLSConfig buildTlsConfig();
    public A withTlsConfig(TLSConfig tlsConfig);
    public Boolean hasTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> withNewTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(TLSConfig item);
    public RemoteReadSpecFluent.TlsConfigNested<A> editTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(TLSConfig item);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(String arg1);
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(StringBuffer arg1);
    public interface BasicAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BasicAuthFluent<RemoteReadSpecFluent.BasicAuthNested<N>> {

            public N and();
            public N endBasicAuth();    }


    public interface TlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSConfigFluent<RemoteReadSpecFluent.TlsConfigNested<N>> {

            public N and();
            public N endTlsConfig();    }


}

==> openshift-model-monitoring-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/RemoteReadSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface RemoteReadSpecFluent<A extends RemoteReadSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBasicAuth instead.
 * @return The buildable object.
 */
@Deprecated public BasicAuth getBasicAuth();
    public BasicAuth buildBasicAuth();
    public A withBasicAuth(BasicAuth basicAuth);
    public Boolean hasBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> withNewBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
    public RemoteReadSpecFluent.BasicAuthNested<A> editBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
    public RemoteReadSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
    public String getBearerToken();
    public A withBearerToken(String bearerToken);
    public Boolean hasBearerToken();
    public A withNewBearerToken(StringBuilder arg1);
    public A withNewBearerToken(int[] arg1,int arg2,int arg3);
    public A withNewBearerToken(char[] arg1);
    public A withNewBearerToken(StringBuffer arg1);
    public A withNewBearerToken(byte[] arg1,int arg2);
    public A withNewBearerToken(byte[] arg1);
    public A withNewBearerToken(char[] arg1,int arg2,int arg3);
    public A withNewBearerToken(byte[] arg1,int arg2,int arg3);
    public A withNewBearerToken(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewBearerToken(String arg1);
    public String getBearerTokenFile();
    public A withBearerTokenFile(String bearerTokenFile);
    public Boolean hasBearerTokenFile();
    public A withNewBearerTokenFile(StringBuilder arg1);
    public A withNewBearerTokenFile(int[] arg1,int arg2,int arg3);
    public A withNewBearerTokenFile(char[] arg1);
    public A withNewBearerTokenFile(StringBuffer arg1);
    public A withNewBearerTokenFile(byte[] arg1,int arg2);
    public A withNewBearerTokenFile(byte[] arg1);
    public A withNewBearerTokenFile(char[] arg1,int arg2,int arg3);
    public A withNewBearerTokenFile(byte[] arg1,int arg2,int arg3);
    public A withNewBearerTokenFile(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewBearerTokenFile(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getProxyUrl();
    public A withProxyUrl(String proxyUrl);
    public Boolean hasProxyUrl();
    public A withNewProxyUrl(StringBuilder arg1);
    public A withNewProxyUrl(int[] arg1,int arg2,int arg3);
    public A withNewProxyUrl(char[] arg1);
    public A withNewProxyUrl(StringBuffer arg1);
    public A withNewProxyUrl(byte[] arg1,int arg2);
    public A withNewProxyUrl(byte[] arg1);
    public A withNewProxyUrl(char[] arg1,int arg2,int arg3);
    public A withNewProxyUrl(byte[] arg1,int arg2,int arg3);
    public A withNewProxyUrl(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewProxyUrl(String arg1);
    public Boolean getReadRecent();
    public A withReadRecent(Boolean readRecent);
    public Boolean hasReadRecent();
    public A withNewReadRecent(String arg1);
    public A withNewReadRecent(boolean arg1);
    public String getRemoteTimeout();
    public A withRemoteTimeout(String remoteTimeout);
    public Boolean hasRemoteTimeout();
    public A withNewRemoteTimeout(StringBuilder arg1);
    public A withNewRemoteTimeout(int[] arg1,int arg2,int arg3);
    public A withNewRemoteTimeout(char[] arg1);
    public A withNewRemoteTimeout(StringBuffer arg1);
    public A withNewRemoteTimeout(byte[] arg1,int arg2);
    public A withNewRemoteTimeout(byte[] arg1);
    public A withNewRemoteTimeout(char[] arg1,int arg2,int arg3);
    public A withNewRemoteTimeout(byte[] arg1,int arg2,int arg3);
    public A withNewRemoteTimeout(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRemoteTimeout(String arg1);
    public A addToRequiredMatchers(String key,String value);
    public A addToRequiredMatchers(Map<String,String> map);
    public A removeFromRequiredMatchers(String key);
    public A removeFromRequiredMatchers(Map<String,String> map);
    public Map<String,String> getRequiredMatchers();
    public <K extends Object,V extends Object>A withRequiredMatchers(Map<String,String> requiredMatchers);
    public Boolean hasRequiredMatchers();
    
/**
 * This method has been deprecated, please use method buildTlsConfig instead.
 * @return The buildable object.
 */
@Deprecated public TLSConfig getTlsConfig();
    public TLSConfig buildTlsConfig();
    public A withTlsConfig(TLSConfig tlsConfig);
    public Boolean hasTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> withNewTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(TLSConfig item);
    public RemoteReadSpecFluent.TlsConfigNested<A> editTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
    public RemoteReadSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(TLSConfig item);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(int[] arg1,int arg2,int arg3);
    public A withNewUrl(char[] arg1);
    public A withNewUrl(StringBuffer arg1);
    public A withNewUrl(byte[] arg1,int arg2);
    public A withNewUrl(byte[] arg1);
    public A withNewUrl(char[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUrl(String arg1);
    public interface BasicAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BasicAuthFluent<RemoteReadSpecFluent.BasicAuthNested<N>> {

            public N and();
            public N endBasicAuth();    }


    public interface TlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSConfigFluent<RemoteReadSpecFluent.TlsConfigNested<N>> {

            public N and();
            public N endTlsConfig();    }


}
